#!/bin/bash

#Change this variables if desired
binary=matmul
folder=study #Caution: If this folder already exists, its contents will be erased
#####################################################
mkdir $folder 2>/dev/null
rm -rf $folder/*

csvname=cycles.csv
echo "maxVL,cache_size,cycles" > $folder/$csvname

#prepare the reference configure file. Do not change this.
cp /shared_folder/tasksim/etc/conf/riscv_reference.conf config.conf
sed -i '/latency_file/c\latency_file = \/shared_folder\/tasksim\/etc\/conf\/varith_100c.lat' config.conf
sed -i '/\[Memory\]/c\\[Memory\]\ninput-buffer = 128' config.conf	
num=`grep -Fn '[DL1Cache]' config.conf | cut -d ':' -f1`


make $binary
export VEHAVE_TRACE_SINGLE_THREAD=1

#Run with two vector lengths
for maxVL in 16 32
do
	#set maxVL
	export VEHAVE_VECTOR_LENGTH=$(( $maxVL * 64 ))
	#run
	trace_name=${binary}_${maxVL}
	VEHAVE_DEBUG_LEVEL=0 VEHAVE_TRACE_FILE=${trace_name}.trace /shared_folder/vehave-EPI-0.7-development-2020-12-01-2200/bin/vehave ./${binary}
	#convert traces to prv
	/shared_folder/vehave-EPI-0.7-development-2020-12-01-2200/share/vehave2prv/vehave2prv ${trace_name}.trace
	#simulate different cache sizes
	for CACHE_SIZE in 128 256 512 1024 2048 4096 
	do
		#sim
		trace_sim_name=${folder}/${trace_name}_sim_${CACHE_SIZE}
		awk -v line=$num -v cache=$CACHE_SIZE 'NR==line,/size*/{sub(/size.*/, "size = "cache)} 1' config.conf > config_${CACHE_SIZE}.conf 
		LD_LIBRARY_PATH=/shared_folder/nanox/lib/debug/:$LD_LIBRARY_PATH /shared_folder/tasksim/bin/tasksim.sh config_${CACHE_SIZE}.conf ${trace_sim_name} ${trace_name}
		
		#read results
		cycles=`cat ${trace_sim_name}.stats | grep "Final cycle count" | awk '{print($NF)}'`
		echo "$maxVL,$CACHE_SIZE,$cycles" >> $folder/$csvname
	done

done

mkdir $folder/original_traces
mv *.{prv,pcf,row,trace} $folder/original_traces
rm -f config.conf
mv config_*.conf $folder/.
